wink snapshot explorer

`Esc`

##
Markdown Content

## Keyboard Shortcuts

### Navigation

`J` / `↓`Next item
`K` / `↑`Previous item
`H`Previous slice
`L`Next slice
`←`Previous snapshot
`→`Next snapshot

### Actions

`⌘``K` / `Ctrl` `K`Open command palette
`/`Focus item search
`O`Focus object filter
`R`Reload snapshot
`E`Export JSON
`D`Toggle dark mode

### View

`[`Toggle sidebar
`?`Show this help
`Esc`Close dialogs / Clear search

Created at

Schema version

Slice count

Tags

### Select a slice to inspect

Choose a state or event slice from the sidebar to view its contents

Slice

Search items Filter objects Expand to depth